@@ -1032,7 +1032,7 @@ lightdm_greeter_get_authentication_user (LightDMGreeter *greeter)
 /**
  * lightdm_greeter_set_language:
  * @greeter: A #LightDMGreeter
- * @language: The language to use for this user.
+ * @language: The language to use for this user in the form of a locale specification (e.g. "de_DE.UTF-8").
  *
  * Set the language for the currently authenticated user.
  **/
@@ -1183,42 +1183,6 @@ lightdm_greeter_get_property (GObject    *object,
     }
 }
 
-static void
-marshal_VOID__STRING_INT (GClosure     *closure,
-                          GValue       *return_value G_GNUC_UNUSED,
-                          guint         n_param_values,
-                          const GValue *param_values,
-                          gpointer      invocation_hint G_GNUC_UNUSED,
-                          gpointer      marshal_data)
-{
-    typedef void (*GMarshalFunc_VOID__STRING_INT) (gpointer     data1,
-                                                   gpointer     arg_1,
-                                                   gint         arg_2,
-                                                   gpointer     data2);
-    register GMarshalFunc_VOID__STRING_INT callback;
-    register GCClosure *cc = (GCClosure*) closure;
-    register gpointer data1, data2;
-
-    g_return_if_fail (n_param_values == 3);
-
-    if (G_CCLOSURE_SWAP_DATA (closure))
-    {
-        data1 = closure->data;
-        data2 = g_value_peek_pointer (param_values + 0);
-    }
-    else
-    {
-        data1 = g_value_peek_pointer (param_values + 0);
-        data2 = closure->data;
-    }
-    callback = (GMarshalFunc_VOID__STRING_INT) (marshal_data ? marshal_data : cc->callback);
-
-    callback (data1,
-              (param_values + 1)->data[0].v_pointer,
-              (param_values + 2)->data[0].v_int,
-              data2);
-}
-
 static void
 lightdm_greeter_finalize (GObject *object)
 {
@@ -1375,7 +1339,7 @@ lightdm_greeter_class_init (LightDMGreeterClass *klass)
                       G_SIGNAL_RUN_LAST,
                       G_STRUCT_OFFSET (LightDMGreeterClass, show_prompt),
                       NULL, NULL,
-                      marshal_VOID__STRING_INT,
+                      NULL,
                       G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_INT);
 
     /**
@@ -1393,7 +1357,7 @@ lightdm_greeter_class_init (LightDMGreeterClass *klass)
                       G_SIGNAL_RUN_LAST,
                       G_STRUCT_OFFSET (LightDMGreeterClass, show_message),
                       NULL, NULL,
-                      marshal_VOID__STRING_INT,
+                      NULL,
                       G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_INT);
 
     /**
@@ -1412,7 +1376,7 @@ lightdm_greeter_class_init (LightDMGreeterClass *klass)
                       G_SIGNAL_RUN_LAST,
                       G_STRUCT_OFFSET (LightDMGreeterClass, authentication_complete),
                       NULL, NULL,
-                      g_cclosure_marshal_VOID__VOID,
+                      NULL,
                       G_TYPE_NONE, 0);
 
     /**
@@ -1428,6 +1392,6 @@ lightdm_greeter_class_init (LightDMGreeterClass *klass)
                       G_SIGNAL_RUN_LAST,
                       G_STRUCT_OFFSET (LightDMGreeterClass, autologin_timer_expired),
                       NULL, NULL,
-                      g_cclosure_marshal_VOID__VOID,
+                      NULL,
                       G_TYPE_NONE, 0);
 }
